Welcome to Animanager's documentation!
======================================

Project website: https://darkfeline.github.io/animanager/

Animanager is a simple anime watching and tracking program.

.. toctree::
   :maxdepth: 2

   commands
   menu
   database
